==> openmsghard-0.0.1.tar.gz: openmsghard-0.0.1/misc.c <==
#include "misc.h"
#include "common.h"

int status_count=0;
int old_len=0;

void usage()
{
  printf("Usage: tmsnc [OPTION(s)]\n"
         "TMSNC is a textbased MSN client written by the IR Group\n\n"
         "OPTION can be one or more of the following:\n"
         "-h               print this help\n"
         "-l <username>    specify your username\n"
         "-u               check wether a newer version of TMSNC is available or not\n\n"
         "Please report bugs to sanoi[at]freeshell.org\n"
         );
}

char *split(str, split, ret)
     char *str;
     char split;
     int ret;
{
  char *ptr;
  int a, b, c=0;

  /* Find the first split-char */
  if(ret!=0)
  {
    for(a=0;a<=strlen(str);a++)
    {
      if(str[a]==split && ++c==ret) 
      { 
        a++; 
        break; 
      }
      if(a==strlen(str)) 
        return NULL;
    }
  } else 
  {
    a = 0;
  }
  
  /* Find the second split-char */
  for(b=a;b<=strlen(str);b++)
    if(str[b]==split) break;
  
  ptr = (char *)malloc(sizeof(char)*(b-a+1));
  strncpy(ptr, &str[a], b-a);
  ptr[b-a]=0x0;
  
  return (char *)ptr;
}

/* Check if addr is a valid e-mail address */
int is_valid_address(addr)
     char *addr;
{
  int i;
  char *ptr;
  for(i=0;i<strlen(addr);i++) 
    if(isspace(addr[i])) return -1;
  if((ptr = strchr(addr, '@'))==NULL) return -1;
  if((ptr = strchr(addr, '.'))==NULL) return -1;
  return 0;
}

void status(text)
     char *text;
{  
  char buf[120];
  int i;
  
  for(i=0;i<old_len;i++)
    printf("\b");
  for(i=0;i<old_len;i++)
    printf(" ");
  for(i=0;i<old_len;i++)
    printf("\b");
  fflush(stdout);
  
  buf[0]='[';
  for(i=1;i<40;i+=2)
  {
    if(i<status_count*2) strncpy(&buf[i], "%%", 2);
    else strncpy(&buf[i], "  ", 2);
  }
  snprintf(&buf[i], sizeof(buf)-i-1, "]   %s", text);
  printf("%s", buf);
  fflush(stdout);
  
  old_len=strlen(buf);
  status_count++;
}

void print_ok(void)
{
  /* XXX to do */
}

void print_fail(void)
{
  /* XXX to do */
}

int err_exit(str)
     char *str;
{
  fprintf(stderr, "\nFatal error: %s\n", str);
  exit(-1);
}

int url_encode(str, ret, ret_len)
     char *str;
     char *ret;
     int ret_len;
{
  int i, a;
  for(i=0, a=0;i<strlen(str) && a<ret_len;i++, a++)
  {
    /* workaround for nickname censoring; make 'm' as in msn 
     * and microsoft hexadecimal */
    if(!isalnum(str[i]) || tolower(str[i])=='m')
    {
      snprintf(&ret[a], ret_len-i, "%%%x", str[i]);
      a+=2;
    }
    else
    {
      ret[a] = str[i];
    }
  }
  ret[a]=0x0;
  return 0;
}

int url_decode(str)
     char *str;
{
  /* XXX dynamic arrays may not be supported by everyone
   * the sad thing is that this is a C99 thing-o
   */
  char buf[strlen(str)];
  char hex[3];
  int x, y;
  
  for (x=0, y=0;x<strlen(str); x++, y++)
  {
    if(str[x]=='%')
    {  
      strncpy(hex, &str[x+1], 2);
      buf[y]=(char)strtol(hex, NULL, 16);
      if(buf[y]=='\t'||buf[y]=='\n'|| buf[y]=='\r')
        buf[y]=' ';
      x+=2;
    } 
    else 
    {
      buf[y]=str[x];
    }
  }
  buf[y]='\0';
  /* XXX this was strcpy() */
  strncpy(str, buf,strlen(str));
  
  return 0;
}



void error2str(err, message, message_len)
     int err;
     char *message;
     int message_len;
{  
  char buf[128];
  switch(err)
  {
    case 200: 
      strcpy(buf, "Invalid syntax"); 
      break;
    case 201: 
      strcpy(buf, "Invalid parameter"); 
      break;
    case 205: 
      strcpy(buf, "Invalid principal"); 
      break;
    case 206: 
      strcpy(buf, "Domain name missing"); 
      break;
    case 207: 
      strcpy(buf, "Already logged in"); 
      break;
    case 208: 
      strcpy(buf, "Invalid principal-name");
      break;
    case 209:
      strcpy(buf, "Nickname change illegal");
      break;
    case 210:
      strcpy(buf, "Principal list full");
      break;
    case 215:
      strcpy(buf, "Principal already on list");
      break;
    case 216: 
      strcpy(buf, "Principal not on list");
      break;
    case 217:
      strcpy(buf, "Principal not on-line"); 
      break;
    case 218: 
      strcpy(buf, "Already in mode"); 
      break;
    case 219:
      strcpy(buf, "Principal is in the opposite list"); 
      break;
    case 280:
      strcpy(buf, "Switchboard failed");
      break;
    case 281:
      strcpy(buf, "Transfer to switchboard failed"); 
      break;
      
    case 300: 
      strcpy(buf, "Required field missing"); 
      break;
    case 302: 
      strcpy(buf, "Not logged in"); 
      break;
      
    case 500: 
      strcpy(buf, "Internal server error"); 
      break;
    case 501: 
      strcpy(buf, "Database server error"); 
      break;
    case 502: 
      strcpy(buf, "Command disabled"); 
      break;
    case 510: 
      strcpy(buf, "File operation failed");
      break;
    case 520:
      strcpy(buf, "Memory allocation failed");
      break;
    case 540: 
      strcpy(buf, "Challenge response failed"); 
      break;
      
    case 602: 
      strcpy(buf, "Peer nameserver is down"); 
      break;
    case 603: 
      strcpy(buf, "Database connection failed"); 
      break;
    case 604: 
      strcpy(buf, "Server is going down"); 
      break;
      
    case 707: 
      strcpy(buf, "Could not create connection"); 
      break;
    case 710: 
      strcpy(buf, "Bad CVR parameters sent"); 
      break;
    case 711: 
      strcpy(buf, "Write is blocking");
      break;
    case 712:
      strcpy(buf, "Session is overloaded"); 
      break;
    case 714:
      strcpy(buf, "Too many sessions");
      break;
    case 715: 
    case 731: 
      strcpy(buf, "Not expected");
      break;
    case 717:
      strcpy(buf, "Bad friend file");
      break;
      
    case 800: 
    case 713: 
      strcpy(buf, "Changing too rapidly"); 
      break;
      
    case 600: 
    case 910: 
    case 912: 
    case 918: 
    case 919: 
    case 921: 
    case 922:
      strcpy(buf, "Server too busy"); 
      break;
    case 911:
    case 917: 
      strcpy(buf, "Autentication failed");
      break;
    case 913:
      strcpy(buf, "Not allowed when hiding");
      break;
    case 914:
    case 915:
    case 916:
    case 605: 
    case 601:
      strcpy(buf, "Server unavailable"); 
      break;
    case 920: 
      strcpy(buf, "Not accepting new principals");
      break;
    case 923: 
      strcpy(buf, "Kids Passport without parental consent");
      break;
    case 924: 
      strcpy(buf, "Passport account not yet verified"); 
      break;
    case 928: 
      strcpy(buf, "Bad ticket"); 
      break;
    default: 
      strcpy(buf, "Unknown error"); 
      break;
  }
  strncpy(message, buf, message_len);
}
void error_handling(char *str) {
	fputs(str,stderr);
	fputc('\n',stderr);
	exit(1);

}
char* utf8_to_euckr( const char* str ){

   iconv_t cd;
   char* outbuf,* out;

   size_t ileft, oleft;

   int err;
   int len;
   len = strlen( str );
   
   ileft = len;
   oleft = len * 2;

   out = outbuf = (char*) malloc( oleft+1 );
   cd = iconv_open( "EUC-KR", "UTF-8" );

   err = iconv( cd, (char**)&str, &ileft, &outbuf, &oleft );
   iconv_close( cd );

   return out;

}
char* euckr_to_utf8( const char* str ){

   iconv_t cd;
   char* outbuf,* out;

   size_t ileft, oleft;

   int err;
   int len;

   len = strlen( str );
	
   ileft = len;
   oleft = len * 2; 
   
   out = outbuf = (char*) malloc( oleft+1 );

   cd = iconv_open( "UTF-8", "EUC-KR" );

   err = iconv( cd, (char**)&str, &ileft, &outbuf, &oleft );
   iconv_close( cd );
   
   return out;

}
void utf8encode(iconv_t ic, char *src, char *dest, int obl)
{
    size_t ibl;
    
    if (ic != (iconv_t) -1) {
        ibl = strlen(src);
        while (ibl > 0 && obl > 0) {
            iconv(ic, &src, &ibl, &dest, &obl);
            iconv(ic, NULL, NULL, NULL, NULL);
            if (ibl > 0) {
                *dest++ = '?'; src++;
                obl--; ibl--;
            } else break;
        }
        if (obl > 0) *dest = 0;
    } else {
        while (*src) {
            *dest = *src++;
            if (*dest >= 0 && *dest < 32) *dest = '?';
            dest++;
        }
        *dest = 0;
    }
}




void set_printbuf(print_buf *print) {
	
	print->header = "\r\n ȣ    ϸ                                             뷮   ";
        print->s_tailer = " ó() ()\r\n";
	print->f_tailer = " () ó() ()\r\n";
	print->m_tailer = " () () ó() ()\r\n";
	print->l_tailer = " () ó() ()\r\n";
	print->help_header = "\r\n\r\nɾ                                                뿹";
	print->help_tailer =  " () ó()\r\n";
	

	print->u_header = euckr_to_utf8(print->header);
	print->u_s_tailer = euckr_to_utf8(print->s_tailer);
	print->u_f_tailer = euckr_to_utf8(print->f_tailer);
	print->u_m_tailer = euckr_to_utf8(print->m_tailer);
	print->u_l_tailer = euckr_to_utf8(print->l_tailer);
	print->u_help_header = euckr_to_utf8(print->help_header);
	print->u_help_tailer = euckr_to_utf8(print->help_tailer);
}

==> openmsghard-1.0.1.tar.gz: openmsghard-1.0.1/misc.c <==
#include "misc.h"
#include "common.h"

int status_count=0;
int old_len=0;

void usage()
{
  printf("Usage: tmsnc [OPTION(s)]\n"
         "TMSNC is a textbased MSN client written by the IR Group\n\n"
         "OPTION can be one or more of the following:\n"
         "-h               print this help\n"
         "-l <username>    specify your username\n"
         "-u               check wether a newer version of TMSNC is available or not\n\n"
         "Please report bugs to sanoi[at]freeshell.org\n"
         );
}

char *split(str, split, ret)
     char *str;
     char split;
     int ret;
{
  char *ptr;
  int a, b, c=0;

  /* Find the first split-char */
  if(ret!=0)
  {
    for(a=0;a<=strlen(str);a++)
    {
      if(str[a]==split && ++c==ret) 
      { 
        a++; 
        break; 
      }
      if(a==strlen(str)) 
        return NULL;
    }
  } else 
  {
    a = 0;
  }
  
  /* Find the second split-char */
  for(b=a;b<=strlen(str);b++)
    if(str[b]==split) break;
  
  ptr = (char *)malloc(sizeof(char)*(b-a+1));
  strncpy(ptr, &str[a], b-a);
  ptr[b-a]=0x0;
  
  return (char *)ptr;
}

/* Check if addr is a valid e-mail address */
int is_valid_address(addr)
     char *addr;
{
  int i;
  char *ptr;
  for(i=0;i<strlen(addr);i++) 
    if(isspace(addr[i])) return -1;
  if((ptr = strchr(addr, '@'))==NULL) return -1;
  if((ptr = strchr(addr, '.'))==NULL) return -1;
  return 0;
}

void status(text)
     char *text;
{  
  char buf[120];
  int i;
  
  for(i=0;i<old_len;i++)
    printf("\b");
  for(i=0;i<old_len;i++)
    printf(" ");
  for(i=0;i<old_len;i++)
    printf("\b");
  fflush(stdout);
  
  buf[0]='[';
  for(i=1;i<40;i+=2)
  {
    if(i<status_count*2) strncpy(&buf[i], "%%", 2);
    else strncpy(&buf[i], "  ", 2);
  }
  snprintf(&buf[i], sizeof(buf)-i-1, "]   %s", text);
  printf("%s", buf);
  fflush(stdout);
  
  old_len=strlen(buf);
  status_count++;
}

void print_ok(void)
{
  /* XXX to do */
}

void print_fail(void)
{
  /* XXX to do */
}

int err_exit(str)
     char *str;
{
  fprintf(stderr, "\nFatal error: %s\n", str);
  exit(-1);
}

int url_encode(str, ret, ret_len)
     char *str;
     char *ret;
     int ret_len;
{
  int i, a;
  for(i=0, a=0;i<strlen(str) && a<ret_len;i++, a++)
  {
    /* workaround for nickname censoring; make 'm' as in msn 
     * and microsoft hexadecimal */
    if(!isalnum(str[i]) || tolower(str[i])=='m')
    {
      snprintf(&ret[a], ret_len-i, "%%%x", str[i]);
      a+=2;
    }
    else
    {
      ret[a] = str[i];
    }
  }
  ret[a]=0x0;
  return 0;
}

int url_decode(str)
     char *str;
{
  /* XXX dynamic arrays may not be supported by everyone
   * the sad thing is that this is a C99 thing-o
   */
  char buf[strlen(str)];
  char hex[3];
  int x, y;
  
  for (x=0, y=0;x<strlen(str); x++, y++)
  {
    if(str[x]=='%')
    {  
      strncpy(hex, &str[x+1], 2);
      buf[y]=(char)strtol(hex, NULL, 16);
      if(buf[y]=='\t'||buf[y]=='\n'|| buf[y]=='\r')
        buf[y]=' ';
      x+=2;
    } 
    else 
    {
      buf[y]=str[x];
    }
  }
  buf[y]='\0';
  /* XXX this was strcpy() */
  strncpy(str, buf,strlen(str));
  
  return 0;
}



void error2str(err, message, message_len)
     int err;
     char *message;
     int message_len;
{  
  char buf[128];
  switch(err)
  {
    case 200: 
      strcpy(buf, "Invalid syntax"); 
      break;
    case 201: 
      strcpy(buf, "Invalid parameter"); 
      break;
    case 205: 
      strcpy(buf, "Invalid principal"); 
      break;
    case 206: 
      strcpy(buf, "Domain name missing"); 
      break;
    case 207: 
      strcpy(buf, "Already logged in"); 
      break;
    case 208: 
      strcpy(buf, "Invalid principal-name");
      break;
    case 209:
      strcpy(buf, "Nickname change illegal");
      break;
    case 210:
      strcpy(buf, "Principal list full");
      break;
    case 215:
      strcpy(buf, "Principal already on list");
      break;
    case 216: 
      strcpy(buf, "Principal not on list");
      break;
    case 217:
      strcpy(buf, "Principal not on-line"); 
      break;
    case 218: 
      strcpy(buf, "Already in mode"); 
      break;
    case 219:
      strcpy(buf, "Principal is in the opposite list"); 
      break;
    case 280:
      strcpy(buf, "Switchboard failed");
      break;
    case 281:
      strcpy(buf, "Transfer to switchboard failed"); 
      break;
      
    case 300: 
      strcpy(buf, "Required field missing"); 
      break;
    case 302: 
      strcpy(buf, "Not logged in"); 
      break;
      
    case 500: 
      strcpy(buf, "Internal server error"); 
      break;
    case 501: 
      strcpy(buf, "Database server error"); 
      break;
    case 502: 
      strcpy(buf, "Command disabled"); 
      break;
    case 510: 
      strcpy(buf, "File operation failed");
      break;
    case 520:
      strcpy(buf, "Memory allocation failed");
      break;
    case 540: 
      strcpy(buf, "Challenge response failed"); 
      break;
      
    case 602: 
      strcpy(buf, "Peer nameserver is down"); 
      break;
    case 603: 
      strcpy(buf, "Database connection failed"); 
      break;
    case 604: 
      strcpy(buf, "Server is going down"); 
      break;
      
    case 707: 
      strcpy(buf, "Could not create connection"); 
      break;
    case 710: 
      strcpy(buf, "Bad CVR parameters sent"); 
      break;
    case 711: 
      strcpy(buf, "Write is blocking");
      break;
    case 712:
      strcpy(buf, "Session is overloaded"); 
      break;
    case 714:
      strcpy(buf, "Too many sessions");
      break;
    case 715: 
    case 731: 
      strcpy(buf, "Not expected");
      break;
    case 717:
      strcpy(buf, "Bad friend file");
      break;
      
    case 800: 
    case 713: 
      strcpy(buf, "Changing too rapidly"); 
      break;
      
    case 600: 
    case 910: 
    case 912: 
    case 918: 
    case 919: 
    case 921: 
    case 922:
      strcpy(buf, "Server too busy"); 
      break;
    case 911:
    case 917: 
      strcpy(buf, "Autentication failed");
      break;
    case 913:
      strcpy(buf, "Not allowed when hiding");
      break;
    case 914:
    case 915:
    case 916:
    case 605: 
    case 601:
      strcpy(buf, "Server unavailable"); 
      break;
    case 920: 
      strcpy(buf, "Not accepting new principals");
      break;
    case 923: 
      strcpy(buf, "Kids Passport without parental consent");
      break;
    case 924: 
      strcpy(buf, "Passport account not yet verified"); 
      break;
    case 928: 
      strcpy(buf, "Bad ticket"); 
      break;
    default: 
      strcpy(buf, "Unknown error"); 
      break;
  }
  strncpy(message, buf, message_len);
}
void error_handling(char *str) {
	fputs(str,stderr);
	fputc('\n',stderr);
	exit(1);

}
char* utf8_to_euckr( const char* str ){

   iconv_t cd;
   char* outbuf,* out;

   size_t ileft, oleft;

   int err;
   int len;
   len = strlen( str );
   
   ileft = len;
   oleft = len * 2;

   out = outbuf = (char*) malloc( oleft+1 );
   cd = iconv_open( "EUC-KR", "UTF-8" );

   err = iconv( cd, (char**)&str, &ileft, &outbuf, &oleft );
   iconv_close( cd );

   return out;

}
char* euckr_to_utf8( const char* str ){

   iconv_t cd;
   char* outbuf,* out;

   size_t ileft, oleft;

   int err;
   int len;

   len = strlen( str );
	
   ileft = len;
   oleft = len * 2; 
   
   out = outbuf = (char*) malloc( oleft+1 );

   cd = iconv_open( "UTF-8", "EUC-KR" );

   err = iconv( cd, (char**)&str, &ileft, &outbuf, &oleft );
   iconv_close( cd );
   
   return out;

}
void utf8encode(iconv_t ic, char *src, char *dest, int obl)
{
    size_t ibl;
    
    if (ic != (iconv_t) -1) {
        ibl = strlen(src);
        while (ibl > 0 && obl > 0) {
            iconv(ic, &src, &ibl, &dest, &obl);
            iconv(ic, NULL, NULL, NULL, NULL);
            if (ibl > 0) {
                *dest++ = '?'; src++;
                obl--; ibl--;
            } else break;
        }
        if (obl > 0) *dest = 0;
    } else {
        while (*src) {
            *dest = *src++;
            if (*dest >= 0 && *dest < 32) *dest = '?';
            dest++;
        }
        *dest = 0;
    }
}




void set_printbuf(print_buf *print) {



        print->header = "\r\n ȣ    ϸ                                             뷮   ";
        print->s_tailer = " ó() () (51)  \r\n";
        print->f_tailer = " () ó() () (51) \r\n";
        print->m_tailer = " () () ó() () (51) \r\n";
        print->l_tailer = " () ó() () (51 ) \r\n";

        print->l_s_tailer = " () ó() () (51)  \r\n";
        print->l_f_tailer = " () () ó() () (51) \r\n";
        print->l_m_tailer = " () () () ó() () (51) \r\n";
        print->l_l_tailer = " () () ó() () (51) \r\n";



        print->help_header = "\r\n\r\nɾ                                                뿹";
        print->help_tailer =  " () ó() \r\n";






        print->u_header = euckr_to_utf8(print->header);
        print->u_s_tailer = euckr_to_utf8(print->s_tailer);
        print->u_f_tailer = euckr_to_utf8(print->f_tailer);
        print->u_m_tailer = euckr_to_utf8(print->m_tailer);
        print->u_l_tailer = euckr_to_utf8(print->l_tailer);
        print->u_l_s_tailer = euckr_to_utf8(print->l_s_tailer);
        print->u_l_f_tailer = euckr_to_utf8(print->l_f_tailer);
        print->u_l_m_tailer = euckr_to_utf8(print->l_m_tailer);
        print->u_l_l_tailer = euckr_to_utf8(print->l_l_tailer);


        print->u_help_header = euckr_to_utf8(print->help_header);
        print->u_help_tailer = euckr_to_utf8(print->help_tailer);
	

/*
	strcpy(print->header , "\r\n ȣ    ϸ                                             뷮   ");
        strcpy(print->s_tailer , " ó() () (51)\r\n");
	strcpy(print->f_tailer , " () ó() () (51)\r\n");
	strcpy(print->m_tailer , " () () ó() () (51)\r\n");
	strcpy(print->l_tailer , " () ó() () (51)\r\n");
	strcpy(print->help_header , "\r\n\r\nɾ                                                뿹");
	strcpy(print->help_tailer ,  " () ó()\r\n");
	
        msn_ic[0] = msn_ic[1] = (iconv_t) -1;
        msn_ic[0] = iconv_open("EUC-KR","UTF-8");
        msn_ic[1] = iconv_open("UTF-8", "EUC-KR");


        utf8encode(msn_ic[1],print->header , print->u_header, 2*MAX_BUF);
        utf8encode(msn_ic[1],print->s_tailer , print->u_s_tailer, 2*MAX_BUF);
        utf8encode(msn_ic[1],print->f_tailer , print->u_f_tailer, 2*MAX_BUF);
        utf8encode(msn_ic[1],print->m_tailer , print->u_m_tailer, 2*MAX_BUF);
        utf8encode(msn_ic[1],print->l_tailer , print->u_l_tailer, 2*MAX_BUF);
        utf8encode(msn_ic[1],print->help_header , print->u_help_header, 2*MAX_BUF);
        utf8encode(msn_ic[1],print->help_tailer , print->u_help_tailer, 2*MAX_BUF);
*/




}
